==> owncloud-8.0.11.tar.bz2: owncloud/apps/updater/l10n/da.js <==
OC.L10N.register(
    "updater",
    {
    "Version not found" : "Version blev ikke fundet",
    "Upgrade is not possible. Your web server does not have permission to remove the following directory:" : "Det er ikke muligt at opgradere. Din webserver har ikke de tilstrækkelige rettigheder til at fjerne den følgende mappe:",
    "Update permissions on this directory and its content or remove it manually first." : "Opdatér rettigheder for denne mappe og dens indhold, eller fjern den manuelt først.",
    "Update failed." : "Opdatering mislykkedes.",
    "The update was unsuccessful. Please check logs at admin page and report this issue to the <a href=\"https://github.com/owncloud/updater/issues/new\" target=\"_blank\">ownCloud community</a>." : "Opdateringen lykkedes ikke. Kontrollér venligst loggen på administratorsiden og rapportér dette problem til <a href=\"https://github.com/owncloud/updater/issues/new\" target=\"_blank\">ownCloud-fællesskabet</a>.",
    "Server error. Please check web server log file for details" : "Serverfejl. Tjek venligst webserverens logfil for yderligere detaljer",
    "Retry" : "Forsøg igen",
    "Here is your backup:" : "Her er din sikkerhedskopi:",
    "Proceed" : "Fortsæt",
    "All done. Click to the link below to start database upgrade." : "Færdig. Klik på linket herunder for at starte opgraderingen af databasen.",
    "Please ask your server administrator to enable PHP zip extension." : "Du bedes anmode din serveradministrator om at aktivere PHP-udvidelsen zip.",
    "Not possible to update %s to %s. Downgrading or skipping major releases is not supported." : "Det er ikke muligt at opdatere %s til %s. Nedgradering eller overspringelse af større udgivelser understøttes ikke.",
    "Make sure that your web server has read access to the following files and directories:" : "Sørg for at sikre, at din webserver har læseadgang til følgende filer og mapper:",
    "Make sure that your web server has write access to the following files and directories:" : "Sørg for at sikre, at din webserver har skriveadgang til følgende filer og mapper:",
    "Updater" : "Updater",
    "Open Update Center" : "Åbn opdateringercenteret",
    "Updates" : "Opdateringer",
    "A new version is available: %s" : "Der er en ny version tligængelig: %s",
    "Up to date. Checked on %s" : "Ajourført. Tjekket per %s",
    "1. Check & Backup" : "1. Tjek & sikkerhedskopi",
    "2. Download & Extract" : "2. Hent og pak ud",
    "3. Replace" : "3. Erstat",
    "Update" : "Opdatér",
    "Backups" : "Sikkerhedskopier",
    "Backup directory" : "Mappe for sikkeredskopier",
    "No backups found" : "Ingen sikkerhedskopier fundet",
    "Backup" : "Sikkerhedskopi",
    "Done on" : "Færdig per",
    "Download" : "Download",
    "Delete" : "Slet"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-8.2.7.tar.bz2: owncloud/apps/updater/l10n/da.js <==
OC.L10N.register(
    "updater",
    {
    "Unable to switch channel." : "Kan ikke skifte kanal.",
    "Version not found" : "Version blev ikke fundet",
    "Upgrade is not possible. Your web server does not have permission to remove the following directory:" : "Det er ikke muligt at opgradere. Din webserver har ikke de tilstrækkelige rettigheder til at fjerne den følgende mappe:",
    "Update permissions on this directory and its content or remove it manually first." : "Opdatér rettigheder for denne mappe og dens indhold, eller fjern den manuelt først.",
    "Update failed." : "Opdatering mislykkedes.",
    "Fetching..." : "Henter...",
    "Retry" : "Forsøg igen",
    "Here is your backup:" : "Her er din sikkerhedskopi:",
    "Proceed" : "Fortsæt",
    "<strong>All done.</strong> Click to the link below to start database upgrade." : "<strong>Færdig.</strong> Klik på linket herunder for at starte database opgradering",
    "Production" : "Produktion",
    "Stable" : "stabilt",
    "Beta" : "Beta",
    "Daily" : "Dagligt",
    "Please ask your server administrator to enable PHP zip extension." : "Du bedes anmode din serveradministrator om at aktivere PHP-udvidelsen zip.",
    "Not possible to update %s to %s. Downgrading or skipping major releases is not supported." : "Det er ikke muligt at opdatere %s til %s. Nedgradering eller overspringelse af større udgivelser understøttes ikke.",
    "Make sure that your web server has read access to the following files and directories:" : "Sørg for at sikre, at din webserver har læseadgang til følgende filer og mapper:",
    "Make sure that your web server has write access to the following files and directories:" : "Sørg for at sikre, at din webserver har skriveadgang til følgende filer og mapper:",
    "Updates" : "Opdateringer",
    "<strong>A new version is available: {{newVersion}}</strong>" : "<strong>En ny version er tilgængelig: {{newVersion}}</strong>",
    "1. Check & Backup" : "1. Tjek & sikkerhedskopi",
    "2. Download & Extract" : "2. Hent og pak ud",
    "3. Replace" : "3. Erstat",
    "Update" : "Opdatér",
    "Update channel:" : "Opdatér kanal:",
    "Updater-Backups" : "Opdaterings-sikkerhedskopier",
    "No backups found." : "Ingen sikkerhedskopier fundet",
    "Backup" : "Sikkerhedskopi",
    "Done on" : "Færdig per",
    "Size" : "Størrelse",
    "Download" : "Download",
    "Delete" : "Slet",
    "Are you sure you want to delete {{entry.title}}" : "Er du sikker på du vil slette {{entry.title}}?",
    "Backup directory" : "Mappe for sikkeredskopier"
},
"nplurals=2; plural=(n != 1);");
